@@ -1,7 +1,7 @@
 from django.contrib import admin
 
 # import models
-from userextensions.models import (Theme, UserFavorite, UserPreference, UserRecent)
+from userextensions.models import (Theme, UserFavorite, UserPreference, UserRecent, ServiceAccount)
 
 
 class ThemeAdmin(admin.ModelAdmin):
@@ -26,8 +26,15 @@ class UserFavoriteAdmin(admin.ModelAdmin):
     list_filter = ["user"]
 
 
+class ServiceAccountAdmin(admin.ModelAdmin):
+    list_display = ("id", "user", "group", "description", "enabled")
+    search_fields = ["user__username", "group__name", "description"]
+    list_filter = ["enabled"]
+
+
 # register models
 admin.site.register(Theme, ThemeAdmin)
 admin.site.register(UserPreference, UserPreferenceAdmin)
 admin.site.register(UserFavorite, UserFavoriteAdmin)
 admin.site.register(UserRecent, UserRecentAdmin)
+admin.site.register(ServiceAccount, ServiceAccountAdmin)
